Module session_api

Module session_api 

Enums

AnonymousHandlerError
struct for typed errors of method anonymous_handler
LoginHandlerError
struct for typed errors of method login_handler
LogoutHandlerError
struct for typed errors of method logout_handler
OidcInitError
struct for typed errors of method oidc_init
OidcLoginError
struct for typed errors of method oidc_login
RegisterUserHandlerError
struct for typed errors of method register_user_handler
SessionHandlerError
struct for typed errors of method session_handler
SessionProjectHandlerError
struct for typed errors of method session_project_handler
SessionViewHandlerError
struct for typed errors of method session_view_handler

Functions

anonymous_handler
login_handler
logout_handler
oidc_init
Errors This call fails if Open ID Connect is disabled, misconfigured or the Id Provider is unreachable.
oidc_login
Errors This call fails if the [AuthCodeResponse] is invalid, if a previous oidcLogin call with the same state was already successfully or unsuccessfully resolved, if the Open Id Connect configuration is invalid, or if the Id Provider is unreachable.
register_user_handler
session_handler
session_project_handler
session_view_handler