oidc_login

Function oidc_login 

pub async fn oidc_login(
    configuration: &Configuration,
    redirect_uri: &str,
    auth_code_response: AuthCodeResponse,
) -> Result<UserSession, Error<OidcLoginError>>
Errors This call fails if the [AuthCodeResponse] is invalid, if a previous oidcLogin call with the same state was already successfully or unsuccessfully resolved, if the Open Id Connect configuration is invalid, or if the Id Provider is unreachable.