Module tasks_api

Module tasks_api 

Enums

AbortHandlerError
struct for typed errors of method abort_handler
ListHandlerError
struct for typed errors of method list_handler
StatusHandlerError
struct for typed errors of method status_handler

Functions

abort_handler
Parameters * force - If true, the task will be aborted without clean-up. You can abort a task that is already in the process of aborting.
list_handler
status_handler