pub enum Aggregation {
MinAggregation(Box<MinAggregation>),
MaxAggregation(Box<MaxAggregation>),
FirstAggregation(Box<FirstAggregation>),
LastAggregation(Box<LastAggregation>),
MeanAggregation(Box<MeanAggregation>),
SumAggregation(Box<SumAggregation>),
CountAggregation(Box<CountAggregation>),
PercentileEstimateAggregation(Box<PercentileEstimateAggregation>),
}Expand description
Aggregation : Aggregation methods for TemporalRasterAggregation. Available variants are min, max, first, last, mean, sum, count, and percentileEstimate. Encountering NO DATA makes the aggregation result NO DATA unless ignoreNoData is true.
Aggregation methods for TemporalRasterAggregation. Available variants are min, max, first, last, mean, sum, count, and percentileEstimate. Encountering NO DATA makes the aggregation result NO DATA unless ignoreNoData is true.
Variants
MinAggregation(Box<MinAggregation>)
MaxAggregation(Box<MaxAggregation>)
FirstAggregation(Box<FirstAggregation>)
LastAggregation(Box<LastAggregation>)
MeanAggregation(Box<MeanAggregation>)
SumAggregation(Box<SumAggregation>)
CountAggregation(Box<CountAggregation>)
PercentileEstimateAggregation(Box<PercentileEstimateAggregation>)