Module data_id

Module data_id 

Enums

DataId
DataId : The identifier for loadable data. It is used in the source operators to get the loading info (aka parametrization) for accessing the data. Internal data is loaded from datasets, external from DataProviders.