pub struct ExpressionParameters {
pub expression: String,
pub map_no_data: bool,
pub output_band: Option<Box<RasterBandDescriptor>>,
pub output_type: RasterDataType,
}Expand description
ExpressionParameters : ## Types The following describes the types used in the parameters.
Fields
expression: StringExpression script Example: \"(A - B) / (A + B)\"
map_no_data: boolShould NO DATA values be mapped with the expression? Otherwise, they are mapped automatically to NO DATA.
output_band: Option<Box<RasterBandDescriptor>>Description about the output
output_type: RasterDataTypeA raster data type for the output
Implementations
Sourceimpl ExpressionParameters
impl ExpressionParameters
Sourcepub fn new(
expression: String,
map_no_data: bool,
output_type: RasterDataType,
) -> ExpressionParameters
pub fn new( expression: String, map_no_data: bool, output_type: RasterDataType, ) -> ExpressionParameters
Types The following describes the types used in the parameters.