pub struct GdalMetadataNetCdfCf {
pub band_offset: i32,
pub cache_ttl: Option<i32>,
pub end: i64,
pub params: Box<GdalDatasetParameters>,
pub result_descriptor: Box<RasterResultDescriptor>,
pub start: i64,
pub step: Box<TimeStep>,
pub type: Type,
}Expand description
GdalMetadataNetCdfCf : Meta data for 4D NetCDF CF datasets
Fields
band_offset: i32A band offset specifies the first band index to use for the first point in time. All other time steps are added to this offset.
cache_ttl: Option<i32>end: i64We use the end to specify the last, non-inclusive valid time point. Queries behind this point return no data. TODO: Alternatively, we could think about using the number of possible time steps in the future.
params: Box<GdalDatasetParameters>result_descriptor: Box<RasterResultDescriptor>start: i64step: Box<TimeStep>type: TypeImplementations
Sourceimpl GdalMetadataNetCdfCf
impl GdalMetadataNetCdfCf
Sourcepub fn new(
band_offset: i32,
end: i64,
params: GdalDatasetParameters,
result_descriptor: RasterResultDescriptor,
start: i64,
step: TimeStep,
type: Type,
) -> GdalMetadataNetCdfCf
pub fn new( band_offset: i32, end: i64, params: GdalDatasetParameters, result_descriptor: RasterResultDescriptor, start: i64, step: TimeStep, type: Type, ) -> GdalMetadataNetCdfCf
Meta data for 4D NetCDF CF datasets