pub struct GdalSource {
pub params: Box<GdalSourceParameters>,
pub type: Type,
}Expand description
GdalSource : The GdalSource is a source operator that reads raster data using GDAL. The counterpart for vector data is the [OgrSource]. ## Errors If the given dataset does not exist or is not readable, an error is thrown.
Fields
params: Box<GdalSourceParameters>type: TypeImplementations
Sourceimpl GdalSource
impl GdalSource
Sourcepub fn new(params: GdalSourceParameters, type: Type) -> GdalSource
pub fn new(params: GdalSourceParameters, type: Type) -> GdalSource
The GdalSource is a source operator that reads raster data using GDAL. The counterpart for vector data is the [OgrSource]. ## Errors If the given dataset does not exist or is not readable, an error is thrown.