pub struct HistogramParameters {
pub bounds: Box<HistogramBounds>,
pub buckets: Box<HistogramBuckets>,
pub column_name: String,
pub interactive: Option<bool>,
}Expand description
HistogramParameters : The parameter spec for Histogram
Fields
bounds: Box<HistogramBounds>If data, it computes the bounds of the underlying data. If { \"min\": ..., \"max\": ... }, one can specify custom bounds.
buckets: Box<HistogramBuckets>The number of buckets. The value can be specified or calculated.
column_name: StringName of the (numeric) vector attribute or raster band to compute the histogram on.
interactive: Option<bool>Flag, if the histogram should have user interactions for a range selection. It is false by default.
Implementations
Sourceimpl HistogramParameters
impl HistogramParameters
Sourcepub fn new(
bounds: HistogramBounds,
buckets: HistogramBuckets,
column_name: String,
) -> HistogramParameters
pub fn new( bounds: HistogramBounds, buckets: HistogramBuckets, column_name: String, ) -> HistogramParameters
The parameter spec for Histogram