pub struct Interpolation {
pub params: Box<InterpolationParameters>,
pub sources: Box<SingleRasterSource>,
pub type: Type,
}Expand description
Interpolation : The Interpolation operator increases raster resolution by interpolating values of an input raster. If queried with a resolution that is coarser than the input resolution, interpolation is not applicable and an error is returned. ## Inputs The Interpolation operator expects exactly one raster input.
Fields
params: Box<InterpolationParameters>sources: Box<SingleRasterSource>type: TypeImplementations
Sourceimpl Interpolation
impl Interpolation
Sourcepub fn new(
params: InterpolationParameters,
sources: SingleRasterSource,
type: Type,
) -> Interpolation
pub fn new( params: InterpolationParameters, sources: SingleRasterSource, type: Type, ) -> Interpolation
The Interpolation operator increases raster resolution by interpolating values of an input raster. If queried with a resolution that is coarser than the input resolution, interpolation is not applicable and an error is returned. ## Inputs The Interpolation operator expects exactly one raster input.