Structs
- Mock
Point Source - MockPointSource : The
MockPointSourceis a source operator that provides mock vector point data for testing and development purposes.
MockPointSource is a source operator that provides mock vector point data for testing and development purposes.