pub struct MockPointSource {
pub params: Box<MockPointSourceParameters>,
pub type: Type,
}Expand description
MockPointSource : The MockPointSource is a source operator that provides mock vector point data for testing and development purposes.
Fields
params: Box<MockPointSourceParameters>type: TypeImplementations
Sourceimpl MockPointSource
impl MockPointSource
Sourcepub fn new(params: MockPointSourceParameters, type: Type) -> MockPointSource
pub fn new(params: MockPointSourceParameters, type: Type) -> MockPointSource
The MockPointSource is a source operator that provides mock vector point data for testing and development purposes.