pub struct MockPointSourceParameters {
pub points: Vec<Coordinate2D>,
pub spatial_bounds: Box<SpatialBoundsDerive>,
}Expand description
MockPointSourceParameters : Parameters for the [MockPointSource] operator.
Fields
points: Vec<Coordinate2D>Points to be output by the mock point source.
spatial_bounds: Box<SpatialBoundsDerive>Defines how the spatial bounds of the source are derived. Defaults to None.
Implementations
Sourceimpl MockPointSourceParameters
impl MockPointSourceParameters
Sourcepub fn new(
points: Vec<Coordinate2D>,
spatial_bounds: SpatialBoundsDerive,
) -> MockPointSourceParameters
pub fn new( points: Vec<Coordinate2D>, spatial_bounds: SpatialBoundsDerive, ) -> MockPointSourceParameters
Parameters for the [MockPointSource] operator.