Module ogr_source

Module ogr_source 

Structs

OgrSource
OgrSource : The OgrSource is a source operator that reads vector data using OGR (part of GDAL). The counterpart for raster data is the [GdalSource]. ## Errors If the given dataset does not exist or is not readable, an error is thrown.

Enums

Type