RasterVectorJoinParameters

Struct RasterVectorJoinParameters 

pub struct RasterVectorJoinParameters {
    pub feature_aggregation: FeatureAggregationMethod,
    pub feature_aggregation_ignore_no_data: Option<bool>,
    pub names: Box<ColumnNames>,
    pub temporal_aggregation: TemporalAggregationMethod,
    pub temporal_aggregation_ignore_no_data: Option<bool>,
}

Fields

feature_aggregation: FeatureAggregationMethod

The aggregation function to use for features covering multiple pixels.

feature_aggregation_ignore_no_data: Option<bool>

Whether to ignore no data values in the aggregation. Defaults to false.

names: Box<ColumnNames>

Specify how the new column names are derived from the raster band names. The ColumnNames type is used to specify how the new column names are derived from the raster band names. - default: Appends " (n)" to the band name with the smallest n that avoids a conflict. - suffix: Specifies a suffix for each input, to be appended to the band names. - rename: A list of names for each new column.

temporal_aggregation: TemporalAggregationMethod

The aggregation function to use for features covering multiple (raster) time steps.

temporal_aggregation_ignore_no_data: Option<bool>

Whether to ignore no data values in the aggregation. Defaults to false.

Implementations