Reprojection

Struct Reprojection 

pub struct Reprojection {
    pub params: Box<ReprojectionParameters>,
    pub sources: Box<SingleRasterOrVectorSource>,
    pub type: Type,
}
Reprojection : The Reprojection operator reprojects data from one spatial reference system to another. It accepts exactly one input which can either be a raster or a vector data stream. The operator produces all data that, after reprojection, is contained in the query rectangle. ## Data Type Specifics The concrete behavior depends on the data type. ### Vector Data The operator reprojects all coordinates of the features individually. The result contains all features that, after reprojection, are intersected by the query rectangle. ### Raster Data To create tiles in the target projection, the operator loads corresponding tiles in the source projection. For each output pixel, the value of the nearest input pixel is used. If parts of a tile are outside of the source extent after projection, the operator produces NO DATA values. ## Inputs The Reprojection operator expects exactly one raster or vector input. ## Errors The operator returns an error if the target projection is unknown or if input data cannot be reprojected.

Fields

params: Box<ReprojectionParameters>sources: Box<SingleRasterOrVectorSource>type: Type

Implementations

Source

impl Reprojection

pub fn new( params: ReprojectionParameters, sources: SingleRasterOrVectorSource, type: Type, ) -> Reprojection

The Reprojection operator reprojects data from one spatial reference system to another. It accepts exactly one input which can either be a raster or a vector data stream. The operator produces all data that, after reprojection, is contained in the query rectangle. ## Data Type Specifics The concrete behavior depends on the data type. ### Vector Data The operator reprojects all coordinates of the features individually. The result contains all features that, after reprojection, are intersected by the query rectangle. ### Raster Data To create tiles in the target projection, the operator loads corresponding tiles in the source projection. For each output pixel, the value of the nearest input pixel is used. If parts of a tile are outside of the source extent after projection, the operator produces NO DATA values. ## Inputs The Reprojection operator expects exactly one raster or vector input. ## Errors The operator returns an error if the target projection is unknown or if input data cannot be reprojected.