pub struct SingleRasterSource {
pub raster: Box<RasterOperator>,
}Expand description
SingleRasterSource : A single raster operator as a source for this operator.
Fields
raster: Box<RasterOperator>Implementations
Sourceimpl SingleRasterSource
impl SingleRasterSource
Sourcepub fn new(raster: RasterOperator) -> SingleRasterSource
pub fn new(raster: RasterOperator) -> SingleRasterSource
A single raster operator as a source for this operator.