pub struct StatisticsParameters {
pub column_names: Option<Vec<String>>,
pub percentiles: Option<Vec<f64>>,
}Expand description
StatisticsParameters : The parameter spec for Statistics
Fields
column_names: Option<Vec<String>>Vector data The names of the attributes to generate statistics for. # Raster data Optional: An alias for each input source. The operator will automatically name the rasters Raster-1, Raster-2, … if this parameter is empty. If aliases are given, the number of aliases must match the number of input rasters. Otherwise an error is returned.
percentiles: Option<Vec<f64>>The percentiles to compute for each attribute.
Implementations
Sourceimpl StatisticsParameters
impl StatisticsParameters
Sourcepub fn new() -> StatisticsParameters
pub fn new() -> StatisticsParameters
The parameter spec for Statistics