pub struct TemporalRasterAggregationParameters {
pub aggregation: Box<Aggregation>,
pub output_type: Option<Option<RasterDataType>>,
pub window: Box<TimeStep>,
pub window_reference: Option<Option<i64>>,
}Expand description
TemporalRasterAggregationParameters : Parameters for the TemporalRasterAggregation operator.
Fields
aggregation: Box<Aggregation>Aggregation method for values within each time window. Encountering NO DATA makes the aggregation result NO DATA unless ignoreNoData is true for the selected aggregation variant.
output_type: Option<Option<RasterDataType>>Optional output raster data type.
window: Box<TimeStep>Window size and granularity for the output time series.
window_reference: Option<Option<i64>>Optional reference timestamp used as the anchor for window boundaries. If omitted, windows are anchored at 1970-01-01T00:00:00Z.
Implementations
Sourceimpl TemporalRasterAggregationParameters
impl TemporalRasterAggregationParameters
Sourcepub fn new(
aggregation: Aggregation,
window: TimeStep,
) -> TemporalRasterAggregationParameters
pub fn new( aggregation: Aggregation, window: TimeStep, ) -> TemporalRasterAggregationParameters
Parameters for the TemporalRasterAggregation operator.