Enums
- Anonymous
Handler Error - struct for typed errors of method
anonymous_handler - Login
Handler Error - struct for typed errors of method
login_handler - Logout
Handler Error - struct for typed errors of method
logout_handler - Oidc
Init Error - struct for typed errors of method
oidc_init - Oidc
Login Error - struct for typed errors of method
oidc_login - Register
User Handler Error - struct for typed errors of method
register_user_handler - Session
Handler Error - struct for typed errors of method
session_handler - Session
Project Handler Error - struct for typed errors of method
session_project_handler - Session
View Handler Error - struct for typed errors of method
session_view_handler
Functions
- anonymous_
handler - login_
handler - logout_
handler - oidc_
init - Errors This call fails if Open ID Connect is disabled, misconfigured or the Id Provider is unreachable.
- oidc_
login - Errors This call fails if the [
AuthCodeResponse] is invalid, if a previous oidcLogin call with the same state was already successfully or unsuccessfully resolved, if the Open Id Connect configuration is invalid, or if the Id Provider is unreachable. - register_
user_ handler - session_
handler - session_
project_ handler - session_
view_ handler