pub async fn oidc_login(
configuration: &Configuration,
redirect_uri: &str,
auth_code_response: AuthCodeResponse,
) -> Result<UserSession, Error<OidcLoginError>>pub async fn oidc_login(
configuration: &Configuration,
redirect_uri: &str,
auth_code_response: AuthCodeResponse,
) -> Result<UserSession, Error<OidcLoginError>>AuthCodeResponse] is invalid, if a previous oidcLogin call with the same state was already successfully or unsuccessfully resolved, if the Open Id Connect configuration is invalid, or if the Id Provider is unreachable.