Enums
- Abort
Handler Error - struct for typed errors of method
abort_handler - List
Handler Error - struct for typed errors of method
list_handler - Status
Handler Error - struct for typed errors of method
status_handler
Functions
- abort_
handler - Parameters *
force- If true, the task will be aborted without clean-up. You can abort a task that is already in the process of aborting. - list_
handler - status_
handler