abort_handler

Function abort_handler 

pub async fn abort_handler(
    configuration: &Configuration,
    id: &str,
    force: Option<bool>,
) -> Result<(), Error<AbortHandlerError>>
Parameters * force - If true, the task will be aborted without clean-up. You can abort a task that is already in the process of aborting.