Structs
- Gdal
Source - GdalSource : The
GdalSourceis a source operator that reads raster data using GDAL. The counterpart for vector data is the [OgrSource]. ## Errors If the given dataset does not exist or is not readable, an error is thrown.
GdalSource is a source operator that reads raster data using GDAL. The counterpart for vector data is the [OgrSource]. ## Errors If the given dataset does not exist or is not readable, an error is thrown.