Structs
- OgrSource
- OgrSource : The
OgrSourceis a source operator that reads vector data using OGR (part of GDAL). The counterpart for raster data is the [GdalSource]. ## Errors If the given dataset does not exist or is not readable, an error is thrown.