TemporalRasterAggregation

Struct TemporalRasterAggregation 

pub struct TemporalRasterAggregation {
    pub params: Box<TemporalRasterAggregationParameters>,
    pub sources: Box<SingleRasterSource>,
    pub type: Type,
}
TemporalRasterAggregation : The TemporalRasterAggregation operator aggregates a raster time series into uniform time windows. The output starts with the first window that contains the query start and contains all windows that overlap the query interval. Pixel values are computed by aggregating all input rasters that contribute to the current window. ## Inputs The TemporalRasterAggregation operator expects exactly one raster input. ## Errors If the aggregation method is first, last, or mean and the input raster has no NO DATA value, an error is returned.

Fields

params: Box<TemporalRasterAggregationParameters>sources: Box<SingleRasterSource>type: Type

Implementations

Source

impl TemporalRasterAggregation

pub fn new( params: TemporalRasterAggregationParameters, sources: SingleRasterSource, type: Type, ) -> TemporalRasterAggregation

The TemporalRasterAggregation operator aggregates a raster time series into uniform time windows. The output starts with the first window that contains the query start and contains all windows that overlap the query interval. Pixel values are computed by aggregating all input rasters that contribute to the current window. ## Inputs The TemporalRasterAggregation operator expects exactly one raster input. ## Errors If the aggregation method is first, last, or mean and the input raster has no NO DATA value, an error is returned.